@@ -8,7 +8,7 @@ class CustomerFilterBackend(LDPPermissionsFilterBackend):
         if request.user.is_anonymous:
             return super().filter_queryset(request, queryset, view)
         else:
-            return queryset.filter(project__members__user=request.user)
+            return queryset.filter(Q(project__members__user=request.user) | Q(owner=request.user))
 
 
 class ProjectFilterBackend(LDPPermissionsFilterBackend):
@@ -30,7 +30,10 @@ class ProjectMemberFilterBackend(LDPPermissionsFilterBackend):
         elif request.user.is_anonymous:
             return super().filter_queryset(request, queryset, view)
         else:
-            return super().filter_queryset(request, queryset, view).filter(
+            objects = super().filter_queryset(request, queryset, view).values_list('pk')
+            return queryset.filter(
                 Q(user=request.user) |
                 Q(project__status='Public') |
-                Q(project__members__user=request.user)).distinct()
+                Q(project__members__user=request.user) |
+                Q(pk__in=objects)
+            ).distinct()
